@@ -105,6 +105,8 @@ void processKeyboard() {
     }
     if (keys[SDLK_UP]) {
         followingMypos = 0;
+        canvas.dx += 0.2 * sin(canvas.rotz * M_PI / 180.0);
+        canvas.dy += 0.2 * cos(canvas.rotz * M_PI / 180.0);
     }
     if (keys[SDLK_DOWN]) {
         followingMypos = 0;
